summaryrefslogtreecommitdiffstats
path: root/app/watchdog_service.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'app/watchdog_service.hpp')
-rw-r--r--app/watchdog_service.hpp15
1 files changed, 8 insertions, 7 deletions
diff --git a/app/watchdog_service.hpp b/app/watchdog_service.hpp
index 0cf1c74..141bdb7 100644
--- a/app/watchdog_service.hpp
+++ b/app/watchdog_service.hpp
@@ -35,6 +35,7 @@ class WatchdogService
bool enabled;
Action expireAction;
TimerUse timerUse;
+ TimerUse expiredTimerUse;
uint64_t interval;
uint64_t timeRemaining;
};
@@ -78,18 +79,18 @@ class WatchdogService
*/
void setTimerUse(TimerUse timerUse);
/** @brief Sets the value of the interval property on the host watchdog
*
* @param[in] interval - The new interval value
*/
- void setInterval(uint64_t interval);
+ void setExpiredTimerUse(TimerUse timerUse);
- /** @brief Sets the value of the timeRemaining property on the host
- * watchdog
+ /** @brief Sets the value of the interval property on the host watchdog
*
- * @param[in] timeRemaining - The new timeRemaining value
+ * @param[in] interval - The new interval value
*/
- void setTimeRemaining(uint64_t timeRemaining);
+ void setInterval(uint64_t interval);
private:
/** @brief sdbusplus handle */
OpenPOWER on IntegriCloud
@@ -78,18 +79,18 @@ class WatchdogService
*/
void setTimerUse(TimerUse timerUse);
- /** @brief Sets the value of the interval property on the host watchdog
+ /** @brief Sets the value of the ExpiredTimerUse property on the host
+ * watchdog
*
@@ -78,18 +79,18 @@ class WatchdogService
*
- * @param[in] interval - The new interval value
+ * @param[in] timerUse - The new timerUse value
*/